API Reference
=============
These are the two public methods that expose the fast-simplification API to
Python.  

.. currentmodule:: fast_simplification

.. autosummary::
   :toctree: _autosummary

   simplify
   simplify_mesh
